<template>
  <div class="container">
    <div class="main-content">
      <div class="list-container">
        <div class="tit">
          <div>
            <Platform style="width: 1em; height: 1em;margin-right: 4px" />
            通知公告
          </div>
          <el-button plain @click="toMore(2)">查看更多</el-button>
        </div>
        <div class="list">
          <div v-for="item in state.noticeList" @click="openDetails('通知公告',item.id)">
            <div><img src="src/assets/images/notice.png"></div>
            <div>
              <div>{{item.title}}</div>
              <span>{{(item.updateTime?item.updateTime:item.createTime).substring(0,16)}}</span>
            </div>
          </div>
        </div>
      </div>

      <div class="login-container list-container">
        <login-form ref="loginRef"/>
      </div>

      <div class="list-container">
        <div class="tit">
          <div>
            <Platform style="width: 1em; height: 1em;margin-right: 4px" />
            机构公示
          </div>
          <el-button plain @click="toMore(4)">查看更多</el-button>
        </div>
        <div class="list">
          <div v-for="item in state.pubList" @click="openDetails('机构公示',item.id)">
            <div><img src="src/assets/images/section.png"></div>
            <div>
              <div>{{item.name}}</div>
              <span>{{(item.updateTime?item.updateTime:item.createTime).substring(0,16)}}</span>
            </div>
          </div>
        </div>
      </div>

      <div class="list-container">
        <div class="tit">
          <div>
            <Platform style="width: 1em; height: 1em;margin-right: 4px" />
            法律法规
          </div>
          <el-button plain @click="toMore(3)">查看更多</el-button>
        </div>
        <div class="list">
          <div v-for="item in state.lawsList" @click="openDetails('法律法规',item.id)">
            <div><img src="src/assets/images/laws.png"></div>
            <div>
              <div>{{item.title}}</div>
              <span>{{(item.updateTime?item.updateTime:item.createTime).substring(0,16)}}</span>
            </div>
          </div>
        </div>
      </div>
    </div>
<!--    <login-form ref="loginRef"/>-->
  </div>
</template>

<script setup>
import {onMounted, ref, reactive, watch, onUnmounted, defineEmits, defineExpose} from "vue"
import { getNotice, getLaws, getPublish } from '@/api/home/homePage'
import useUserStore from '@/store/modules/user'
import LoginForm from './loginForm'
import {ElMessage} from "element-plus";

const route = useRoute()
const router = useRouter()

const state = reactive({
  noticeList: [],
  lawsList: [],
  pubList: []
})
const emit = defineEmits(['toMore','openDetails'])
const redirect = ref(undefined);

onMounted(()=>{
  getNoticeList()
  getLawsList()
  getPubList()
})

onUnmounted(()=>{

})

watch(route, (newRoute) => {
    redirect.value = newRoute.query && newRoute.query.redirect;
}, { immediate: true })

const toMore=(num)=>{
  emit('toMore',num)
}

const openDetails = (type,id)=>{
  emit('openDetails',type,id)
}

const getNoticeList = async ()=>{
  const res = await getNotice({title: '', content: '', pageNum: 1, pageSize: 5})
  if(res.code == 200){
    state.noticeList = res.data.list
  }else{
    ElMessage.warning(res.message)
  }
}

const getLawsList = async ()=>{
  const res = await getLaws({title: '', content: '', pageNum: 1, pageSize: 5})
  if(res.code == 200){
    state.lawsList = res.data.list
  }else{
    ElMessage.warning(res.message)
  }
}

const getPubList = async ()=>{
  const res = await getPublish({title: '', content: '', pageNum: 1, pageSize: 5})
  if(res.code == 200){
    state.pubList = res.data.list
  }else{
    ElMessage.warning(res.message)
  }
}

defineExpose({
  getNoticeList,
  getLawsList,
  getPubList
})

</script>

<style lang='scss' scoped>
.container {
  width: 100%;
  display: flex;
  flex-direction: column;
  align-items: center;
  margin-top: 160px;

  .main-content{
    width: 1200px;
    height: calc(100vh - 250px);
    margin: 15px 0;
    color: #333;
    display: flex;
    flex-wrap: wrap;
    align-items: center;

    .list-container{
      border-radius: 4px;
      width: calc(50% - 7.5px);
      height: calc(50% - 7.5px);
      margin-bottom: 15px;
      box-shadow: 1px 1px 3px rgba(0,0,0,.04);
      padding: 0 15px;
      overflow: hidden;
      background: #fff url("../../assets/images/city-bg.png") no-repeat right bottom;
      background-size: 40% auto;

      &:nth-of-type(2n+1){
        margin-right: 15px;
      }

      .tit{
        display: flex;
        align-items: center;
        justify-content: space-between;
        height: 50px;
        border-bottom: 1px solid #ebeef5;
        &>div{
          display: flex;
          align-items: center;
          font-size: 18px;
          color: #425f9f;
          font-weight: bolder;
        }
      }
      .list{
        width: 100%;
        height: calc(100% - 60px);
        padding: 5px 0;
        margin-top: 5px;
        display: flex;
        flex-direction: column;
        justify-content: space-around;

        &>div{
          width: 100%;
          padding: 5px;
          display: flex;
          align-items: center;
          cursor: pointer;

          border-radius: 4px;

          &>div:first-of-type{
            width: 40px;
            height: 40px;
            border-radius: 4px;
            background: #eaf1ff;
            margin-right: 10px;
            display: flex;
            align-items: center;
            justify-content: center;
            img{
              width: 28px;
              height: 28px;
            }
          }
          &>div:last-of-type{
            width: calc(100% - 50px);
            font-size: 16px;
            div{
              width: 100%;
              white-space: nowrap;
              overflow: hidden;
              text-overflow: ellipsis;
              font-family: "PingFang SC";
              margin-bottom: 4px;
            }
            span{
              color: #999;
            }
          }
          &:hover{
            background: #f5f5f5;
          }
        }
      }
    }
    .login-container{
      background: url("../../assets/images/login-bg.jpg");
    }

  }
}
</style>
